require 'spec_helper'

describe Skrill::Payment::Configuration do
  shared_examples_for 'an option' do
    after do
      Skrill::Payment::Configuration.configure do |config|
        config.public_send("#{option}=", nil)
      end
    end

    context 'when a Hash is given' do
      before do
        Skrill::Payment::Configuration.configure(option => value)
      end

      specify { expect(Skrill::Payment::Configuration.public_send(option)).to eq(value) }
    end

    context 'when a block is given' do
      before do
        Skrill::Payment::Configuration.configure do |config|
          config.public_send("#{option}=", value)
        end
      end

      specify { expect(Skrill::Payment::Configuration.public_send(option)).to eq(value) }
    end

    context 'when value is not defined' do
      let(:value)  { nil }
      specify { expect(Skrill::Payment::Configuration.public_send(option)).to eq(nil) }
    end
  end

  describe '.merchant_email' do
    it_should_behave_like 'an option' do
      let(:option) { :merchant_email }
      let(:value)  { 'merchant@example.com' }
    end
  end

  describe '.merchant_password' do
    it_should_behave_like 'an option' do
      let(:option) { :merchant_password }
      let(:value)  { '7813258ef8c6b632dde8cc80f6bda62f' }
    end
  end

  describe '.currency' do
    it_should_behave_like 'an option' do
      let(:option) { :currency }
      let(:value)  { 'AUD' }
    end
  end

  describe '.subject' do
    it_should_behave_like 'an option' do
      let(:option) { :subject }
      let(:value)  { 'Your bacon is ready' }
    end
  end

  describe '.note' do
    it_should_behave_like 'an option' do
      let(:option) { :note }
      let(:value)  { 'More bacon is available on our website.' }
    end
  end

  describe '.http_proxy' do
    it_should_behave_like 'an option' do
      let(:option) { :http_proxy }
      let(:value)  { 'More proxy' }
    end
  end
end
