require 'spec_helper'

describe Skrill::Payment do
  let(:payment) do
    Skrill::Payment.new do |payee|
      payee.email  = 'customer@example.com'
    end
  end

  let(:request)       { double(error_message: error_message, successful?: successful) }
  let(:error_message) { nil }
  let(:successful)    { true }

  before do
    allow(Skrill::Payment::Request).to receive(:post).and_return(request)
    allow(Skrill::Payment::Configuration).to receive(:serialized_data).and_return(subject: 'Bacon Coins')
  end

  describe '#deliver' do
    context 'when providing a block' do
      it 'sends a payment request' do
        expect(Skrill::Payment::Request).to receive(:post).with({subject: 'Bacon Coins'}, {email: 'customer@example.com'})

        payment.deliver
      end
    end

    context 'when providing a Hash' do
      let(:payment) { Skrill::Payment.new(email: 'customer@example.com') }

      it 'sends a payment request' do
        expect(Skrill::Payment::Request).to receive(:post).with({subject: 'Bacon Coins'}, {email: 'customer@example.com'})

        payment.deliver
      end
    end
  end

  describe '#successful?' do
    context 'when the payment was successful' do
      it 'returns true' do
        payment.deliver

        expect(payment).to be_successful
      end
    end

    context 'when the payment was not successful' do
      let(:error_message) { 'bacon not found' }
      let(:successful)    { false }

      it 'returns false' do
        payment.deliver

        expect(payment).to_not be_successful
      end
    end
  end

  describe '#error' do
    context 'when the payment was successful' do
      it 'returns nil' do
        payment.deliver

        expect(payment.error_message).to be_nil
      end
    end

    context 'when the payment was not successful' do
      let(:error_message) { 'bacon not found' }
      let(:successful)    { false }

      it 'returns an error message' do
        payment.deliver

        expect(payment.error_message).to eq('bacon not found')
      end
    end
  end
end
